
#### REPLICATION CODE FOR EXPERT vs EXPERT ANALYSIS ####

##  2 Objects are in memory ##
##  final is a merged 2002 Chapel Hill + 2002 Benoit Laver data set, used for comparing experts.
##  hooghe is a merged 2006 Chapel Hill + 2009 European Election Study data set + EP6 Constitutional NOMINATE scores

#### Compares Chapel Hill 2002 estimates to Benoit-Laver 2002 estimates ###
#### Includes Figure 1 and Table 1 results ###

load("replication.rda")


### FIGURE 1A
fset <- 0.5	#smoothing window
par(mar=c(5,5,1,1))
plot(final$lrgen, final$Mean.benoitLR,xlab="Chapel Hill left-right",ylab="Benoit-Laver left-right",
	bty="n",type="n", cex.lab=1.2 , xlim=c(0,10), ylim=c(0,20))
points(final$lrgen, final$Mean.benoitLR, pch=19, col="grey")
selector <- (final$lrgen <3.3)
lines(lowess(final$lrgen[selector], final$Mean.benoitLR[selector],f=fset),lwd=2)
selector <- (final$lrgen < 6.7) & (final$lrgen > 3.3)
lines(lowess(final$lrgen[selector], final$Mean.benoitLR[selector],f=fset),lwd=2)
selector <- (final$lrgen> 6.7)
lines(lowess(final$lrgen[selector], final$Mean.benoitLR[selector],f=fset),lwd=2)

### FIGURE 1B
fset <- 0.5	#smoothing window
par(mar=c(5,5,1,1))
plot(final$position, final$Mean.benoitEU,xlab="Chapel Hill integration scale",ylab="Benoit-Laver EU authority",
	bty="n",type="n", cex.lab=1.2, xlim=c(1,7), ylim=c(4,18))
points(final$position, final$Mean.benoitEU, pch=19, col="grey")
selector <- (final$position > 5)
lines(lowess(final$position[selector], final$Mean.benoitEU[selector],f=fset),lwd=2)
selector <- (final$position < 5) & (final$position > 3)
lines(lowess(final$position[selector], final$Mean.benoitEU[selector],f=fset),lwd=2)
selector <- (final$position < 3)
lines(lowess(final$position[selector], final$Mean.benoitEU[selector],f=fset),lwd=2)


### TABLE 1B: EU Integration ###

#0.88 correlation, full range
nrow(final)
cor(final$position, final$Mean.benoitEU,use="pairwise.complete.obs")

#0.27 on pro-integration, N=46
selector <- (final$position >= 5)
sum(selector)
cor(final$position[selector], final$Mean.benoitEU[selector],use="pairwise.complete.obs")

#0.89 on anti-integration, N=9
selector <- (final$position <= 3)
sum(selector)
cor(final$position[selector], final$Mean.benoitEU[selector],use="pairwise.complete.obs")

# 0.21 opposing direction, N=12
selector <- (final$position < 5) & (final$position > 3)
sum(selector)
cor(final$position[selector], final$Mean.benoitEU[selector],use="pairwise.complete.obs")

par(mfrow=c(1,2))
plot(final$position[selector], final$Mean.benoitEU[selector],xlim=c(3,5))
abline(lm(final$Mean.benoitEU[selector]~final$position[selector]))

# Compare standard deviations for moderate integrationist parties (according to CHES)
final$marker <- (final$position>3) & (final$position<5)
t.test(final$std_position[final$marker==1],final$std_position[final$marker==0])
t.test(final$std_lrgen[final$marker==1],final$std_lrgen[final$marker==0])


### Response to Marks, Steenbergen and Hooghe:
# 0.21 opposing direction, N=12
selector <- (final$position <= 5) & (final$position >= 3)
sum(selector)
cor(final$position[selector], final$Mean.benoitEU[selector],use="pairwise.complete.obs")
plot(final$position[selector], final$Mean.benoitEU[selector])
abline(lm(final$Mean.benoitEU[selector]~final$position[selector]))



### TABLE 1A: LEFT-RIGHT ###
#r=0.82, n=14
selector <- (final$lrgen <= 3.3)
sum(selector)
cor(final$lrgen[selector], final$Mean.benoitLR[selector],use="pairwise.complete.obs")

#r=0.83, n=17
selector <- (final$lrgen >= 6.7)
sum(selector)
cor(final$lrgen[selector], final$Mean.benoitLR[selector],use="pairwise.complete.obs")

#r=0.93, n=36
selector <- (final$lrgen < 6.7) & (final$lrgen > 3.3)
sum(selector)
cor(final$lrgen[selector], final$Mean.benoitLR[selector],use="pairwise.complete.obs")


### FIGURE 2: EU INTEGRATION HISTOGRAM ###
par(mar=c(5,5,4,2))
hist(hooghe$Chapel_Hill_Integration,xlab="EU integration position", main="",col="gray",cex.lab=1.1)


### TABLE 2: CORRELATIONS OF EXPERTS VS VOTERS ###

### EU Integration, Full Range
cor(hooghe$Chapel_Hill_LeftRight, hooghe$LR.mean,use="pairwise.complete.obs")
cor(hooghe$Chapel_Hill_Integration, hooghe$EU.mean, use="pairwise.complete.obs")
length(na.omit(hooghe$Chapel_Hill_LeftRight))

### EU Integration, pro-Integration and Euroskeptic
selector3 <- (hooghe$Chapel_Hill_Integration > 4)
selector4 <- (hooghe$Chapel_Hill_Integration <= 4)
cor(hooghe$Chapel_Hill_Integration[selector3], hooghe$EU.mean[selector3], use="pairwise.complete.obs")
cor(hooghe$Chapel_Hill_Integration[selector4], hooghe$EU.mean[selector4], use="pairwise.complete.obs")
sum(selector3,na.rm=TRUE)
sum(selector4,na.rm=TRUE)

### EU Integration, Moderates
selector5 <- (hooghe$Chapel_Hill_Integration < 6) & (hooghe$Chapel_Hill_Integration > 2)
cor(hooghe$Chapel_Hill_Integration[selector5], hooghe$EU.mean[selector5], use="pairwise.complete.obs")
sum(selector5,na.rm=TRUE)

### EU Integration, dichotomized
hooghe.dichot <- (hooghe$Chapel_Hill_Integration >= 2)
cor(hooghe.dichot, hooghe$EU.mean, use="pairwise.complete.obs")

### Left-Right, rightist and leftist parties
selector1 <- (hooghe$Chapel_Hill_LeftRight > mean(hooghe$Chapel_Hill_LeftRight, na.rm=TRUE))
selector2 <- (hooghe$Chapel_Hill_LeftRight < mean(hooghe$Chapel_Hill_LeftRight, na.rm=TRUE))
cor(hooghe$Chapel_Hill_LeftRight[selector1], hooghe$LR.mean[selector1], use="pairwise.complete.obs")
cor(hooghe$Chapel_Hill_LeftRight[selector2], hooghe$LR.mean[selector2], use="pairwise.complete.obs")
sum(selector1,na.rm=TRUE)
sum(selector2,na.rm=TRUE)


### CORRELATIONS OF EXPERTS VS. CONSTITUTIONAL NOMINATE
#Correlates at r=0.75, N=99
plot(hooghe$nom_constitution,hooghe$Chapel_Hill_Integration,xlab="Nominate (constitutional)",ylab="Chapel Hill integration ")
cor(hooghe$Chapel_Hill_Integration, hooghe$nom_constitution,use="pairwise.complete.obs")

#Euroskeptic half half correlates well at 0.56, N=23
selector <- (hooghe$nom_constitution <= 0)
sum(selector,na.rm=TRUE) 
plot(hooghe$nom_constitution[selector], hooghe$Chapel_Hill_Integration[selector],xlab="Nominate (constitutional)",ylab="Chapel Hill integration")
cor(hooghe$Chapel_Hill_Integration[selector], hooghe$nom_constitution[selector],use="pairwise.complete.obs")

#Europhile half correlates well at 0.06, N=76
selector <- (hooghe$nom_constitution >= 0) 
sum(selector,na.rm=TRUE) 
plot(hooghe$nom_constitution[selector], hooghe$Chapel_Hill_Integration[selector],xlab="Nominate (constitutional)",ylab="Chapel Hill integration")
cor(hooghe$Chapel_Hill_Integration[selector], hooghe$nom_constitution[selector],use="pairwise.complete.obs")


### FIGURE 3: CONSTITUTIONAL NOMINATE VS EXPERTS
fset <- 0.5	#smoothing window
par(mar=c(5,5,1,1))
plot(hooghe$nom_constitution, hooghe$Chapel_Hill_Integration,
	xlab="Nominate (constitutional)",
	ylab="Chapel Hill integration scale",
	bty="n",type="n", cex.lab=1.2, xlim=c(-1,1), ylim=c(1,7))

hooghe <- hooghe[!is.na(hooghe$Chapel_Hill_Integration),]
hooghe <- hooghe[!is.na(hooghe$nom_constitution),]

points(hooghe$nom_constitution, hooghe$Chapel_Hill_Integration, pch=19, col="grey")
selector <- (hooghe$nom_constitution >= 0)
sum(selector)
lines(lowess(hooghe$nom_constitution[selector], hooghe$Chapel_Hill_Integration[selector],f=fset),lwd=2)
selector <- (hooghe$nom_constitution <= 0)
sum(selector)
lines(lowess(hooghe$nom_constitution[selector], hooghe$Chapel_Hill_Integration[selector],f=fset),lwd=2)


